@@ -1,7 +1,9 @@
 from collections import defaultdict
 from pathlib import Path
 from typing import Union
+
 import numpy as np
+
 from deep_utils.utils.logging_utils import log_print
 
 
@@ -9,7 +11,11 @@ class CSVLogger:
     def __init__(self, csv_path: Union[Path, str], logger=None, verbose=1):
         self.csv_path = csv_path
         self.logs: dict = defaultdict(list)
-        log_print(logger, f"Successfully created CSVLogger that saves to {self.csv_path}", verbose=verbose)
+        log_print(
+            logger,
+            f"Successfully created CSVLogger that saves to {self.csv_path}",
+            verbose=verbose,
+        )
 
     def __call__(self, epoch=None, **logs):
         for key, val in logs.items():
@@ -18,6 +24,7 @@ class CSVLogger:
 
     def __save(self):
         import pandas as pd
+
         columns = list(self.logs.keys())
         values = np.array(list(self.logs.values())).T
         df = pd.DataFrame(values, columns=columns)
