@@ -1,4 +1,4 @@
-from .main import (
+from .dir_utils import (
     cp_mv_all,
     crawl_directory_dataset,
     dir_train_test_split,
@@ -9,4 +9,6 @@ from .main import (
     split_segmentation_dirs,
     split_xy_dir,
     transfer_directory_items,
+    combine_directory_of_directories,
+    file_incremental
 )
