@@ -1,6 +1,6 @@
 import torch
 from deep_utils.utils.logging_utils.logging_utils import log_print
-from deep_utils.utils.object_utils.object_utils import get_attributes
+from deep_utils.utils.object_utils.object_utils import get_obj_variables
 
 
 class TorchUtils:
@@ -8,7 +8,7 @@ class TorchUtils:
     def save_config_to_weight(weight_path, config, logger=None, verbose=1):
 
         best_weight = torch.load(weight_path)
-        for k, v in get_attributes(config).items():
+        for k, v in get_obj_variables(config).items():
             if k not in best_weight:
                 best_weight[k] = v
             else:
