@@ -3,3 +3,5 @@ from .object_detection import *
 from .object_tracker import *
 from .torch_vision import *
 from .face_recognition import *
+from .vision_utils import *
+from .ocr import *
