@@ -1,6 +1,8 @@
-from typing import Union
 from abc import abstractmethod
+from typing import Union
+
 import numpy as np
+
 from deep_utils.main_abs.main import MainClass
 
 
@@ -13,10 +15,28 @@ class ObjectDetector(MainClass):
         self.class_names: Union[list, None, np.ndarray] = None
 
     @abstractmethod
-    def detect_objects(self, img, is_rgb, confidence=None, iou_thresh=None, classes=None, get_time=False, **kwargs):
+    def detect_objects(
+        self,
+        img,
+        is_rgb,
+        confidence=None,
+        iou_thresh=None,
+        classes=None,
+        get_time=False,
+        **kwargs
+    ):
         pass
 
     @abstractmethod
-    def detect_dir(self, dir_, confidence=None, iou_thresh=None, classes=None,
-                   extensions=('.png', '.jpg', '.jpeg'), save_results=False, save_in_file=False, **kwargs):
+    def detect_dir(
+        self,
+        dir_,
+        confidence=None,
+        iou_thresh=None,
+        classes=None,
+        extensions=(".png", ".jpg", ".jpeg"),
+        save_results=False,
+        save_in_file=False,
+        **kwargs
+    ):
         pass
